@@ -95,12 +95,19 @@ folks_tp_lowlevel_connection_open_contact_list_channel_async (
       connection_ensure_channel_cb, result, NULL, G_OBJECT (conn));
 }
 
-/* XXX: ideally, we'd either make this static or hide it in the .metadata file,
- * but neither seems to be supported (without breaking the binding to the async
- * function) */
+/**
+ * folks_tp_lowlevel_connection_open_contact_list_channel_finish:
+ * @lowlevel: a #FolksTpLowlevel
+ * @result: the async result
+ * @error: a #GError, or %NULL
+ *
+ * Finish opening a Telepathy Contact List Channel.
+ *
+ * Returns: (transfer none): the ensured-valid #TpChannel
+ */
 TpChannel *
 folks_tp_lowlevel_connection_open_contact_list_channel_finish (
-    FolksTpLowlevel *tp_lowlevel,
+    FolksTpLowlevel *lowlevel,
     GAsyncResult *result,
     GError **error)
 {
@@ -195,9 +202,6 @@ folks_tp_lowlevel_connection_get_contacts_by_handle_async (
       G_OBJECT (conn));
 }
 
-/* XXX: ideally, we'd either make this static or hide it in the .metadata file,
- * but neither seems to be supported (without breaking the binding to the async
- * function) */
 /**
  * folks_tp_lowlevel_connection_get_contacts_by_handle_finish:
  * @tp_lowlevel: a #FolksTpLowlevel
@@ -307,9 +311,6 @@ folks_tp_lowlevel_connection_get_contacts_by_id_async (
       G_OBJECT (conn));
 }
 
-/* XXX: ideally, we'd either make this static or hide it in the .metadata file,
- * but neither seems to be supported (without breaking the binding to the async
- * function) */
 /**
  * folks_tp_lowlevel_connection_get_contacts_by_id_finish:
  * @tp_lowlevel: a #FolksTpLowlevel
@@ -478,7 +479,7 @@ iterate_on_channels (TpConnection *conn,
     }
 
     if (callback)
-      callback (channel, cb_obj);
+      callback (channel, NULL, cb_obj);
   }
 }
 
@@ -511,16 +512,16 @@ got_channels_cb (TpProxy *conn,
 
 /**
  * folks_tp_lowlevel_connection_connect_to_new_group_channels:
- * @tp_lowlevel: a #FolksTpLowlevel
+ * @lowlevel: a #FolksTpLowlevel
  * @conn: the connection to use
- * @callback: function to call on completion
+ * @callback: (scope call): function to call on completion
  * @user_data: (closure): user data to pass to @callback
  *
  * Connect to the NewChannels signal.
  */
 void
 folks_tp_lowlevel_connection_connect_to_new_group_channels (
-    FolksTpLowlevel *tp_lowlevel,
+    FolksTpLowlevel *lowlevel,
     TpConnection *conn,
     FolksTpLowlevelNewGroupChannelsCallback callback,
     gpointer user_data)
